@@ -13,7 +13,7 @@ logger.setLevel(logging.INFO)
 
 class SsConverter:
     def __init__(self):
-        self._supported_rudolph_seasons = [2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2020]
+        self._supported_rudolph_seasons = [2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020]
         self._rudolph_season_base = 2020  # 2020 bases on times swam 2019
 
         self._supported_fina_seasons = {'SCM': [2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020],
@@ -363,6 +363,12 @@ class SsConverter:
     def get_rudolph_season_base(self):
         return self._rudolph_season_base
 
+    def set_fina_season_base(self, course, season):
+        self._fina_season_base[course] = season
+
+    def set_rudolph_season_base(self, season):
+        self._rudolph_season_base = season
+
     @staticmethod
     def get_agegroup_json_from_agegroup_url(agegroup_url):
         strlist = agegroup_url.split('_')
@@ -402,10 +408,22 @@ class SsConverter:
         return '%s_%s' % (strlist[0], strlist[0])
 
     @staticmethod
-    def to_year_fraction(date_in):
+    def get_year_fraction_from_datetime(date_in):
         # not ultimatively accurate as it does not take leap years into account
         return (float(date_in.strftime("%j")) - 1) / 366 + float(date_in.strftime("%Y"))
 
+    @staticmethod
+    def get_year_fraction_from_ssdate(ssdate):
+        date = datetime.strptime(ssdate, "%Y-%m-%d")
+        # not ultimatively accurate as it does not take leap years into account
+        return (float(date.strftime("%j")) - 1) / 366 + float(date.strftime("%Y"))
+
+    @staticmethod
+    def get_year_fraction_from_today():
+        date = datetime.today()
+        # not ultimatively accurate as it does not take leap years into account
+        return (float(date.strftime("%j")) - 1) / 366 + float(date.strftime("%Y"))
+
     @staticmethod
     def get_seconds_from_swimtime(swimtime):
         """
